# PyGalGen
Toolkit used for generation and validation of Galaxy tool
definition files of python programs

## Installation
The tool can be installed by pip using this command:
```
pip install pygalgen
```
